Discover Packages
github.com/ypsu/efftesting
efft
internal
package
Version:
v0.260225.0
Opens a new window with list of versions in this module.
Published: Feb 25, 2026
License: 0BSD
Opens a new window with license information.
Imports: 13
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
Documentation
¶
Package internal contains internal helper functions.
Detab removes the leading tab characters from the string if it's a multiline string.
That's because efftesting uses backticks for multiline strings and tab indents them.
type Location struct {
Fname string
Line int
}
Location represents a line in a file.
The filename is absolute.
Replacer contains the new expectations for a set of locations.
Apply applies are stored replacements to a given file.
ApplyAll applies all replacements to all files.
Replace marks the current caller's location to be replaced with newstr.
Source Files
¶
Click to show internal directories.
Click to hide internal directories.